@@ -3,11 +3,11 @@ package EO::Storage;
 use strict;
 use warnings;
 use EO;
-our $VERSION = "0.91";
+our $VERSION = "0.92";
 our @ISA = qw(EO);
 
-sub load : abstract;
-sub save : abstract;
+sub load : Abstract;
+sub save : Abstract;
 
 1;
 
